/*
 * [The "BSD licence"]
 * Copyright (c) 2013 Dandelion
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Dandelion nor the names of its contributors
 * may be used to endorse or promote products derived from this software
 * without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.github.dandelion.webanalytics.core;

import com.github.dandelion.core.asset.web.AssetsRequestContext;

import javax.servlet.ServletRequest;

/**
 * Request Context for Web Analytics
 */
public class WebAnalyticsRequestContext {
    public static final String WEB_ANALYTICS_TOKEN = "%WEB_ANALYTICS_TOKEN%";
    private AssetsRequestContext context;
    private ServletRequest servletRequest;

    public WebAnalyticsRequestContext(ServletRequest servletRequest, AssetsRequestContext context) {
        this.context = context;
        this.servletRequest = servletRequest;
    }

    public static WebAnalyticsRequestContext get(ServletRequest servletRequest) {
        return new WebAnalyticsRequestContext(servletRequest, AssetsRequestContext.get(servletRequest));
    }

    public WebAnalyticsRequestContext storeValue(String key, String value) {
        servletRequest.setAttribute("WebAnalyticsRequestContext-"+key, value);
        return this;
    }

    /**
     * Set-up web analytics with stored provider and token
     * @return WebAnalyticsRequestContext
     */
    public WebAnalyticsRequestContext setup() {
        String provider = (String) servletRequest.getAttribute("WebAnalyticsRequestContext-provider");
        String token = (String) servletRequest.getAttribute("WebAnalyticsRequestContext-token");
        if(provider != null && token != null) {
            context.addScopes(provider).addParameter(provider + "-template", WEB_ANALYTICS_TOKEN, token);
            servletRequest.removeAttribute("WebAnalyticsRequestContext-provider");
            servletRequest.removeAttribute("WebAnalyticsRequestContext-token");
        }
        return this;
    }
}
